confidence_score_heatmap: Confidence Score Heat Map

View source: R/confidence_score_heatmap.R

confidence_score_heatmapR Documentation

Confidence Score Heat Map

Description

Confidence scores displayed on a colour spectrum across generated methods and assessed claims, split into predicted replication outcomes (TRUE/FALSE).

Usage

confidence_score_heatmap(confidence_scores = NULL, data_outcomes = NULL)

Arguments

confidence_scores

A data frame of confidence scores generated from the aggregation methods in the form of data_confidence_scores. Defaults to data_confidence_scores if no argument supplied.

data_outcomes

A data frame of unique claims and the associated binary outcome in the form of data_outcomes. If no argument supplied then defaults to data_outcomes supplied within package.

Value

Plot in viewer

Examples

confidence_score_heatmap(data_confidence_scores, data_outcomes)


aggreCAT documentation built on May 4, 2026, 5:07 p.m.