Display a ridge plot of confidence scores for each aggregation method faceted by its linear, non-linear and Bayesian characteristic.

confidence_score_ridgeplot(confidence_scores = NULL)

Arguments

confidence_scores

A data frame of confidence scores in long format in the form of data_confidence_scores

Value

A density ridge plot of aggregation methods

Examples

if (FALSE) confidence_scores_ridgeplot(data_confidence_scores)