data_ratings.RdAnonymized expert judgements of known-outcome claims, assessed at the 2019 SIPS repliCATS workshop
data_ratingsA table with 6880 rows and 7 columns:
character string identifying whether the round was 1 (pre-discussion) or 2 (post-discussion)
character string of the claim ids (25 unique claims total)
character string of anonymized IDs for each participant (25 participants included in this dataset)
character string for the question type, with four options: direct_replication, involved_binary, belief_binary, or comprehension
character string for the type of response coded in the row, with five options: three_point_lower, three_point_best, three_point_upper, binary_question, or likert_binary
numeric value for the participant's response
character string of group IDs that contained the participants