A table of prior means, to be fed into the BayPRIORsAgg aggregation method

data_supp_priors

Format

A tibble of 25 rows and 2 columns

paper_id

character string with a unique id for each row corresponding to the assessed claim (from 125 papers total)

prior_means

numeric with the average prior probability for the claim corresponding to the paper_id