data_supp_quiz: A table of scores on the quiz to assess prior knowledge, to...

data_supp_quizR Documentation

A table of scores on the quiz to assess prior knowledge, to be fed into the QuizWAgg aggregation method

Description

A table of scores on the quiz to assess prior knowledge, to be fed into the QuizWAgg aggregation method

Usage

data_supp_quiz

Format

A tibble 19 rows and 2 columns

user_name

factor for anonymized IDs for each participant

quiz_score

numeric for the participant's score on the quiz (min of 0, max of 16, NA if no questions answered)

quiz_score_even

numeric quiz scores where all questions are weighted equally (the original quiz score assigned only half marks for true/false questions)

quiz_score_stats

numeric participant score based only on questions pertaining to statistics


aggreCAT documentation built on May 4, 2026, 5:07 p.m.