postprocess_judgements.RdStandardise the output from aggregation method's. This function is called by every aggregation method as a final step.
postprocess_judgements(method_output)tibble created from one of the aggregation methods after
pre-processing' with columns for the aggregation method, paper_id, aggregated_judgement and
n_experts
A tibble of confidence scores cs for each paper_id, corresponding
with an aggregation method (character).