Process input data with filters and meaningful variable names.

This function is called at the head of every aggregation method function.

preprocess_judgements(
  expert_judgements,
  round_2_filter = TRUE,
  three_point_filter = TRUE,
  percent_toggle = FALSE
)

Arguments

expert_judgements

A dataframe with the same variables (columns) as data_ratings.

round_2_filter

Note that the IDEA protocol results in both a Round 1 and Round 2 set of probabilities for each claim. Unless otherwise specified, we will assume that the final Round 2 responses (after discussion) are being referred to.

three_point_filter

Defaults TRUE to filter three point estimates. FALSE will filter the involved_binary question.

percent_toggle

Change the values to probabilities from percentages. Default is FALSE

Value

a long tibble of expert judgements, with six columns: round, paper_id, user_name, element (i.e. question type), and value (i.e. participant response).

Details

This pre-processing function takes input data in the format of data_ratings and outputs a dataframe that:

  1. Applies any filters or manipulations required by the aggregation method.

  2. Converts the input data into variables with more meaningful names for coding, to avoid errors in the wrangling process.

Examples

if (FALSE) preprocess_judgements(data_ratings)