weight_interval: Weighting method: Width of intervals

View source: R/weight_interval.R

weight_intervalR Documentation

Weighting method: Width of intervals

Description

Calculates weights by interval width

Usage

weight_interval(expert_judgements)

Arguments

expert_judgements

A dataframe in the form of data_ratings

Details

This function is used inside IntervalWAgg for aggregation type "IntWAgg". It calculates the width of each three-point judgement (upper - lower), then returns the weight as the inverse of this interval.

Value

A tibble in the form of the input expert_judgements argument with additional columns supplying the calculated weight for each row's observation.

See Also

Other weighting functions: weight_asym(), weight_nIndivInterval(), weight_outlier(), weight_reason(), weight_reason2(), weight_varIndivInterval()


aggreCAT documentation built on May 4, 2026, 5:07 p.m.