View source: R/weight_nIndivInterval.R
| weight_nIndivInterval | R Documentation |
Weighted by the rescaled interval width within individuals across claims.
weight_nIndivInterval(expert_judgements)
expert_judgements |
A dataframe in the form of data_ratings |
This function is used inside IntervalWAgg for aggregation types "IndIntWAgg",
"IndIntAsymWAgg" and "KitchSinkWAgg". Interval width weights are rescaled
relative to an individuals interval widths across all claims.
w\_nIndivInterval_i,c = \frac1\fracU_i,c-L_i,c\max\left({(U_i,d-L_i,d):d=1,...,C}\right)ascii
A tibble in the form of the input expert_judgements argument with additional columns
supplying the calculated weight for each row's observation.
Other weighting functions:
weight_asym(),
weight_interval(),
weight_outlier(),
weight_reason(),
weight_reason2(),
weight_varIndivInterval()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.