View source: R/weight_outlier.R
| weight_outlier | R Documentation |
This method down-weights outliers.
weight_outlier(expert_judgements)
expert_judgements |
A dataframe in the form of data_ratings |
This function is used by LinearWAgg to weighting functions for the aggregation type
"OutWAgg". Outliers are given less weight by using the squared difference between the
median of an individual's best estimates across all claims and their best estimate
for the claim being assessed:
\loadmathjax
\mjdeqnd_i,c = \left(median{B_i,c__i=1,...,N} - B_i,c\right)^2ascii
Weights are given by 1 minus the proportion of the individual's squared difference relative to the maximum squared difference for the claim across all individuals:
\mjdeqnw\_out_i = 1 - \fracd_i,c\max(d_c))ascii
A tibble in the form of the input expert_judgements argument with additional columns
supplying the calculated weight for each row's observation.
Other weighting functions:
weight_asym(),
weight_interval(),
weight_nIndivInterval(),
weight_reason(),
weight_reason2(),
weight_varIndivInterval()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.