View source: R/weight_reason.R
| weight_reason | R Documentation |
This function is used by ReasoningWAgg to weighting functions for the aggregation
type "ReasonWAgg". Calculates weights based on the number of judgement reasoning
methods used by an individual
weight_reason(expert_reasons)
expert_reasons |
A dataframe in the form of data_supp_reasons |
Individuals' weight is equal to the maximum number of judgement reasons given
A tibble of three columns paper_id, user_name, and reason_count
Other weighting functions:
weight_asym(),
weight_interval(),
weight_nIndivInterval(),
weight_outlier(),
weight_reason2(),
weight_varIndivInterval()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.