Calculates weights based on the variability of interval widths within individuals.

weight_varIndivInterval(expert_judgements)

Arguments

expert_judgements

A dataframe in the form of data_ratings

Details

This function is used inside IntervalWAgg for aggregation types "VarIndIntWAgg" and "KitchSinkWAgg". It calculates the difference between individual's upper and lower estimates, then calculates the variance in this interval across each individual's claim assessments. \[w\_varIndivInterval_{i} = var{(U_{i,d}-L_{i,d}):c=1,...,C}\]