data_supp_priors.RdA table of prior means, to be fed into the BayPRIORsAgg aggregation method
data_supp_priorsA tibble of 25 rows and 2 columns
character string with a unique id for each row corresponding to the assessed claim (from 125 papers total)
numeric with the average prior probability for the claim corresponding to the paper_id