data_supp_quiz.RdA table of scores on the quiz to assess prior knowledge, to be fed into the QuizWAgg aggregation method
data_supp_quizA tibble 19 rows and 2 columns
factor for anonymized IDs for each participant
numeric for the participant's score on the quiz (min of 0, max of 16, NA if no questions answered)