| data_supp_quiz | R Documentation |
A table of scores on the quiz to assess prior knowledge, to be fed into the QuizWAgg aggregation method
data_supp_quiz
A tibble 19 rows and 2 columns
factor for anonymized IDs for each participant
numeric for the participant's score on the quiz (min of 0, max of 16, NA if no questions answered)
numeric quiz scores where all questions are weighted equally (the original quiz score assigned only half marks for true/false questions)
numeric participant score based only on questions pertaining to statistics
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.