data_supp_reasons.RdCategories of reasons provided by participants for their expert judgements
data_supp_reasonsa tibble with 625 rows and 15 columns
character string for the paper ID
character string for participant ID
numeric (0:1); references to statistical power calculations within the article, or other discussion within the article of sample size planning.
numeric (0:1); references to blinding of participants to which condition they were in (single blinding) or blinding of both the participants and the experimenters to the conditions (double blinding).
numeric (0:4); any references to the effect size that indicate that the participant considered the size of the effect when assessing the claim. Don’t use if the term "effect size" is used in unrelated ways, but err on the side of considering statements as relevant to the participant’s assessment.
numeric (0:3); references to when the effect was an interaction effect (rather than a direct effect).
numeric (0:2); references to the inclusion, absence, or size of the uncertainty measure for a given effect.
numeric (0:3); references to the characteristics of the sample population or subjects used in a study that affect the participant’s assessment of the claim, including references to low response rate and any other questions or appreciation of the sampling practices.
numeric (0:4); combines 2 nodes for references to the adequacy (or not) of the statistical power of the study &/or sample size.
numeric (0:2); references to a test of statistical significance for the claim as it impacts on the participant’s assessment. This explicitly includes p-values, t-values, critical alpha and p-rep.
numeric (0:2); references to QRPs, 'questionable research practices', any explicit variation of these terms, or for any specific type of QRP mentioned by name (e.g. cherry-picking, HARKing, and p-hacking). Also include any QRP mentioned by name that is not specified above.
numeric (0:2); references to the date of publication, for example in relation to something being published prior to the 'replication crisis' within the relevant discipline, or a study being difficult to re-run now because of changes in social expectations.
numeric (0:2); combines 2 nodes for references to the reputation of the authors and/or institutions involved in the original study.
numeric (0:2); references to specific discipline or sub-discipline reputation, e.g., “in light of failed priming effect studies” and/or comparisons between disciplines.
numeric (0:1); references to the reputation of the journal.