preprocess_judgements.RdProcess input data with filters and meaningful variable names.
This function is called at the head of every aggregation method function.
preprocess_judgements(
expert_judgements,
round_2_filter = TRUE,
three_point_filter = TRUE,
percent_toggle = FALSE
)A dataframe with the same variables (columns) as data_ratings.
Note that the IDEA protocol results in both a Round 1 and Round 2 set of probabilities for each claim. Unless otherwise specified, we will assume that the final Round 2 responses (after discussion) are being referred to.
Defaults TRUE to filter three point estimates. FALSE will
filter the involved_binary question.
Change the values to probabilities from percentages. Default is FALSE
a long tibble of expert judgements, with six columns:
round, paper_id, user_name, element (i.e. question type),
and value (i.e. participant response).
This pre-processing function takes input data in the format of data_ratings and outputs a dataframe that:
Applies any filters or manipulations required by the aggregation method.
Converts the input data into variables with more meaningful names for coding, to avoid errors in the wrangling process.
if (FALSE) preprocess_judgements(data_ratings)