weight_nIndivInterval.RdWeighted by the rescaled interval width within individuals across claims.
weight_nIndivInterval(expert_judgements)A dataframe in the form of data_ratings
This function is used inside IntervalWAgg for aggregation types "IndIntWAgg",
"IndIntAsymWAgg" and "KitchSinkWAgg". Interval width weights are rescaled
relative to an individuals interval widths across all claims.
\[w\_nIndivInterval_{i,c} = \frac{1}{\frac{U_{i,c}-L_{i,c}}{\max\left({(U_{i,d}-L_{i,d}):d=1,...,C}\right)}}\]