This method down-weights outliers.

weight_outlier(expert_judgements)

Arguments

expert_judgements

A dataframe in the form of data_ratings

Details

This function is used by LinearWAgg to calculate weights for the aggregation type "OutWAgg". Outliers are given less weight by using the squared difference between the median of an individual's best estimates across all claims and their best estimate for the claim being assessed: \[d_{i,c} = \left(median{{B_{i,c}}_{_{i=1,...,N}}} - B_{i,c}\right)^2\]

Weights are given by 1 minus the proportion of the individual's squared difference relative to the maximum squared difference for the claim across all individuals:

\[w\_out_{i} = 1 - \frac{d_{i,c}}{\max({d_c})})\]