weight_reason.RdThis function is used by ReasoningWAgg to calculate weights for the aggregation
type "ReasonWAgg". Calculates weights based on the number of judgement reasoning
methods used by an individual
weight_reason(expert_reasons)A dataframe in the form of data_supp_reasons
Individuals' weight is equal to the maximum number of judgement reasons given