weight_reason2.RdThis function is used by ReasoningWAgg to calculate weights for the aggregation
type "ReasonWAgg2". Weights are based on the number and diversity of reasoning
methods used by the participant to support their judgement.
weight_reason2(expert_reasons)A dataframe in the form of data_supp_reasons
An individual's weight is a product of the number of reasons given in support of their judgement and the diversity of these reasons. \[w\_{varReason}_{i,c} =\sum_{r=1}^{R} \mathbf{CR_i}(c,r) \cdot (1 - \frac{\sum_{c=1}^C \mathbf{CR_i}(c,r)}{C})\]